@@ -80,12 +80,11 @@ def switch_to_monorepo_root(directory=None,files=None):
     monorepo_root = get_monorepo_root(directory=directory,files=files)
     if str(monorepo_root) not in sys.path:
         sys.path.insert(0, str(monorepo_root))
+    return str(monorepo_root)
 def get_all_imports(directory=None,sysroot=None):
-    sysroot = sysroot or get_initial_caller_dir()
-    directory = directory or sysroot
+    directory = directory or get_initial_caller_dir()
     files = get_py_files(directory=directory)
-    switch_to_monorepo_root(directory=directory,files=files)
-    for glo in [glo for glo in globs.get('files') if glo]:
+    sysroot = sysroot or switch_to_monorepo_root(directory=directory)
+    for glo in files:
         imp = get_import_with_sysroot(glo, sysroot)
         dynamic_import(imp, globals())
-
